import 'package:project_core/core/model/AppResponse.dart';
import 'package:project_core/default/bloc/DefaultBloc.dart';
import 'package:project_core/default/repository/DefaultGraphqlRepository.dart';
import 'package:flutter/material.dart';

import '../../app/model/Campaign.dart';
import '../../app/provider/graphql/query/CampaignQuery.dart';
import '../../graphql/GraphQLClientInstance.dart';
import '../widget/Error.dart';

class ExemploBlocGraphqlPadraoPage extends StatefulWidget {
  ExemploBlocGraphqlPadraoPage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _ExemploBlocGraphqlPadraoPageState createState() =>
      _ExemploBlocGraphqlPadraoPageState();
}

class _ExemploBlocGraphqlPadraoPageState
    extends State<ExemploBlocGraphqlPadraoPage> {
  //Inicialização do bloc generico
  DefaultBloc _compaignBloc = DefaultBloc(
      "Campanhas",
      DefaultGraphqlRepository((json) => Campaign.fromJson(json),
          GraphQLClientInstance.instance.client, CampaignQuery()));

  @override
  void initState() {
    super.initState();
    _compaignBloc.fetchAll();
  }

  @override
  void dispose() {
    super.dispose();
    _compaignBloc.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: RefreshIndicator(
        onRefresh: () => _compaignBloc.fetchAll(),
        child: StreamBuilder<AppResponse<List<dynamic>>>(
          stream: _compaignBloc.streamOut,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              switch (snapshot.data.status) {
                case Status.LOADING:
                  return Loading(
                    loadingMessage: snapshot.data.message,
                  );
                  break;
                case Status.COMPLETED:
                  return ListView.builder(
                      itemCount: snapshot.data.body.length,
                      itemBuilder: (BuildContext context, int index) {
                        Campaign campaign = snapshot.data.body[index];
                        return ListTile(
                            title: Text(campaign.name),
                            subtitle: Text(campaign.startDate));
                      });
                  break;
                case Status.ERROR:
                  return Error(
                    errorMessage: snapshot.data.message,
                    onRetryPressed: () => _compaignBloc.fetchAll(),
                  );
                  break;
                case Status.WAITING:
                  // TODO: Handle this case.
                  break;
              }
            }
            return Container();
          },
        ),
      ),
    );
  }
}
