import 'package:flutter/material.dart';
import 'package:project_core/core/model/AppResponse.dart';

import '../../app/bloc/CampaignBloc.dart';
import '../../app/model/Campaign.dart';
import '../widget/Error.dart';

class ExemploBlocGraphqlPage extends StatefulWidget {
  ExemploBlocGraphqlPage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _ExemploBlocGraphqlState createState() => _ExemploBlocGraphqlState();
}

class _ExemploBlocGraphqlState extends State<ExemploBlocGraphqlPage> {
  CampaignBloc _campaignBloc = CampaignBloc();

  @override
  void initState() {
    super.initState();
    _campaignBloc.fetchAll();
  }

  @override
  void dispose() {
    super.dispose();
    _campaignBloc.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: RefreshIndicator(
        onRefresh: () => _campaignBloc.fetchAll(),
        child: StreamBuilder<AppResponse<List<Campaign>>>(
          stream: _campaignBloc.streamOut,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              switch (snapshot.data.status) {
                case Status.LOADING:
                  return Loading(
                    loadingMessage: snapshot.data.message,
                  );
                  break;
                case Status.COMPLETED:
                  return ListView.builder(
                      itemCount: snapshot.data.body.length,
                      itemBuilder: (BuildContext context, int index) {
                        Campaign campaign = snapshot.data.body[index];
                        return ListTile(
                            title: Text(campaign.name),
                            subtitle: Text(campaign.startDate));
                      });
                  break;
                case Status.ERROR:
                  return Error(
                    errorMessage: snapshot.data.message,
                    onRetryPressed: () => _campaignBloc.fetchAll(),
                  );
                  break;
                case Status.WAITING:
                  // TODO: Handle this case.
                  break;
              }
            }
            return Container();
          },
        ),
      ),
    );
  }
}
