import 'package:flutter/material.dart';
import 'package:project_core/core/model/AppResponse.dart';

import '../../app/bloc/TransactionBloc.dart';
import '../../app/model/Transaction.dart';
import '../widget/Error.dart';

class ExemploBlocRestPage extends StatefulWidget {
  ExemploBlocRestPage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _ExemploBlocRestPageState createState() => _ExemploBlocRestPageState();
}

class _ExemploBlocRestPageState extends State<ExemploBlocRestPage> {
  TransactionBloc _transactionBloc = TransactionBloc();

  @override
  void initState() {
    super.initState();
    _transactionBloc.fetchAll();
  }

  @override
  void dispose() {
    super.dispose();
    _transactionBloc.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: RefreshIndicator(
        onRefresh: () => _transactionBloc.fetchAll(),
        child: StreamBuilder<AppResponse<List<Transaction>>>(
          stream: _transactionBloc.streamOut,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              switch (snapshot.data.status) {
                case Status.LOADING:
                  return Loading(
                    loadingMessage: snapshot.data.message,
                  );
                  break;
                case Status.COMPLETED:
                  return ListView.builder(
                      itemCount: snapshot.data.body.length,
                      itemBuilder: (BuildContext context, int index) {
                        Transaction transaction = snapshot.data.body[index];
                        return ListTile(
                            title: Text(transaction.loja),
                            subtitle: Text(transaction.valor));
                      });
                  break;
                case Status.ERROR:
                  return Error(
                    errorMessage: snapshot.data.message,
                    onRetryPressed: () => _transactionBloc.fetchAll(),
                  );
                  break;
                case Status.WAITING:
                  // TODO: Handle this case.
                  break;
              }
            }
            return Container();
          },
        ),
      ),
    );
  }
}
