import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class ValidationUtil {
  static FormFieldValidator<String> empty(String msg) {
    return (value) {
      if (value.trim().isEmpty) {
        return msg;
      }
      return null;
    };
  }

  static FormFieldValidator<String> email(String msg) {
    return (value) {
      if (value.trim().isEmpty)
        return msg;
      else {
        final emailRegex = RegExp(
            r"^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,253}[a-zA-Z0-9])?)*$");
        if (emailRegex.hasMatch(value))
          return null;
        else
          return msg;
      }
    };
  }

  static FormFieldValidator<String> length(String msg, int size) {
    return (value) {
      String newValor = value.trim();
      if (newValor.isEmpty || newValor.length < size) {
        return msg;
      }
      return null;
    };
  }

  static FormFieldValidator<String> lengthMin(String msg, int size) {
    return (value) {
      String newValor = value.trim();
      if (newValor.isEmpty || newValor.length > size) {
        return msg;
      }
      return null;
    };
  }

  static FormFieldValidator<String> lengthMax(String msg, int size) {
    return (value) {
      String newValor = value.trim();
      if (newValor.isEmpty || newValor.length <= size) {
        return msg;
      }
      return null;
    };
  }

  static FormFieldValidator<String> confirmPassword(
      String msg, String password) {
    return (value) {
      String newValor = value.trim();
      if (newValor.isEmpty || password != value) {
        return msg;
      }
      return null;
    };
  }

  static FormFieldValidator<String> compose(
      List<FormFieldValidator<String>> validators) {
    return (valor) {
      for (final validador in validators) {
        final validatorMsg = validador(valor);
        if (validatorMsg != null) return validatorMsg;
      }
      return null;
    };
  }

  static void showMsg(GlobalKey<ScaffoldState> key, String msg, int duration) {
    key.currentState.showSnackBar(SnackBar(
      content: new Text(msg),
      duration: new Duration(seconds: duration),
    ));
  }
}
