import 'package:flutter_test/flutter_test.dart';
import 'package:project_core/core/exception/AppException.dart';
import 'package:project_core/env/EnvConfig.dart';
import 'package:project_core_example/app/model/Transaction.dart';
import 'package:project_core_example/app/repository/TransactionRepository.dart';
import 'package:project_core_example/env/env.dart';

void main() {
  Env.instance.setEnv(env);
  group('Teste Repository e RestProvider', () {
    TransactionRepository transactionRepository = TransactionRepository();
    int id = 2000;

    test('fetchAll', () async {
      List<Transaction> list = await transactionRepository.fetchAll();
      expect(list, isNotNull);
      expect(list, isNotEmpty);
      Transaction transaction = list[0];
      expect(transaction.id, isNotNull);
    });

    test('fetchById', () async {
      Transaction transaction = await transactionRepository.fetchById(1);
      expect(transaction, isNotNull);
      expect(transaction.id, isNotNull);
    });

    test('insert', () async {
      Transaction newTransaction =
          Transaction(id, "Quarteto", "R\$ 10,00", "2020-01-01", true);
      try {
        await transactionRepository.insert(newTransaction);
        Transaction transaction = await transactionRepository.fetchById(id);
        expect(transaction, isNotNull);
        expect(transaction.id, isNotNull);
        expect(transaction.id, id);
      } catch (e) {
        fail(e.toString());
      }
    });

    test('update', () async {
      Transaction updateTransaction = await transactionRepository.fetchById(id);
      expect(updateTransaction, isNotNull);
      expect(updateTransaction.id, isNotNull);
      expect(updateTransaction.id, id);
      updateTransaction.loja = "BIG";
      await transactionRepository.update(updateTransaction);
      Transaction transaction = await transactionRepository.fetchById(id);
      expect(transaction, isNotNull);
      expect(transaction.id, isNotNull);
      expect(transaction.loja, "BIG");
    });

    test('delete', () async {
      try {
        await transactionRepository.delete(id);
        Transaction transaction = await transactionRepository.fetchById(id);
        expect(transaction, isNull);
      } on NotFoundException catch (e) {
        expect(true, true);
      }
    });
  });
}
