import 'package:project_core/core/bloc/NavigationBloc.dart';
import 'package:project_core/core/exception/AppException.dart';
import 'package:project_core/core/model/AuthToken.dart';
import 'package:project_core/core/storage/AuthTokenStorage.dart';
import 'package:dio/dio.dart';

class TokenInterceptor extends Interceptor {
  ///Intercepta a requisição para verificar se o token de acesso é válido
  @override
  Future onRequest(RequestOptions options) async {
    if (options.extra.containsKey("token") && options.extra["token"]) {
      AuthToken token = await AuthTokenStorage.instance.getAuthToken();
      if (token == null || token.isTokenExpired()) {
        NavigationBloc.instance.navigateLogout(
            message:
                "Por questão de segurança será necessário realizar o login.");
        throw UnauthorizedException("Token de acesso é inválido.");
      }
      String typeToken = token.tokenType == null ? 'Bearer' : token.tokenType;
      options.headers['Authorization'] = "$typeToken ${token.token}";
    }
    options.extra.remove("token");
    print(options.data);
    super.onRequest(options);
  }
}
