import 'dart:convert';

import 'package:project_core/core/exception/AppException.dart';
import 'package:project_core/core/model/AuthToken.dart';
import 'package:shared_preferences/shared_preferences.dart';

class AuthTokenStorage {
  static final AuthTokenStorage instance = AuthTokenStorage._();

  AuthToken _authToken;

  AuthTokenStorage._();

  Future<AuthToken> getAuthToken<T extends AuthToken>() async {
    if (_authToken == null) {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      String token = prefs.get("auth_token");
      if (token == null) {
        throw TokenStorageException("Token não encontrado");
      }
      _authToken = AuthToken.fromJson(jsonDecode(token));
    }
    return _authToken;
  }

  Future<void> putAuthToken<T extends AuthToken>(T token) async {
    try {
      SharedPreferences prefs = await SharedPreferences.getInstance();
      prefs.setString("auth_token", jsonEncode(token));
      _authToken = token;
    } catch (e) {
      throw TokenStorageException("Falha ao inserir o token nas preferências!");
    }
  }

  void removeToken() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.remove("auth_token");
  }

  AuthToken get authToken => _authToken;
}
